# Code of Conduct and Respectful Inclusive Collaboration Guidelines

CIRES Earth Lab and Environmental Data Science Innovation & Inclusion Lab (ESIIL) are committed to building, maintaining, and fostering an inclusive, kind, collaborative, and diverse transdisciplinary environmental data science community, whose members feel welcome, supported, and safe to contribute ideas and knowledge.

The Forest Carbon Codefest will follow all aspects of the ESIIL Code of Conduct (below).

**All community members are responsible for creating this culture, embodying our values, welcoming diverse perspectives and ways of knowing, creating safe inclusive spaces, and conducting ethical science as guided by FAIR (Findable, Accessible, Interoperable, Reusable) and CARE (Collective Benefit, Authority to Control, Responsibility, and Ethics) principles for scientific and Indigenous data management, governance, and stewardship.**

### Our values

ESIIL’s vision is grounded in the conviction that innovation and breakthroughs in environmental data science will be precipitated by a diverse, collaborative, curious, and inclusive research community empowered by open data and infrastructure, cross-sector and community partnerships, team science, and engaged learning.

As such, our core values center people through inclusion, kindness, respect, collaboration, and genuine relationships. They also center innovation, driven by collaborative, cross-sector science and synthesis, open, accessible data and tools, and fun, diverse teams. Finally, they center learning, propelled by curiosity and accessible, inclusive training, and education opportunities.

### When and how to use these guidelines

These guidelines outline behavior expectations for ESIIL community members. Your participation in the ESIIL network is contingent upon following these guidelines in all ESIIL activities, including, but not limited to, participating in meetings, webinars, hackathons, working groups, hosted or funded by ESIIL, as well as email lists and online forums such as GutHub, Slack, and Twitter. These guidelines have been adapted from those of the International Arctic Research Policy Committee, the Geological Society of America, the American Geophysical Union, the University Corporation for Atmospheric Research, The Carpentries, and others. We encourage other organizations to adapt these guidelines for use in their own meetings.

**Note:** Working groups and hackathon/codefest teams are encouraged to discuss these guidelines and what they mean to them, and will have the opportunity to add to them to specifically support and empower their team. Collaborative and behavior commitments complement data use, management, authorship, and access plans that commit to CARE and FAIR principles.

# Behavior Agreements

ESIIL community members are expected to act professionally and respectfully in all activities, such that each person, regardless of gender, gender identity or expression, sexual orientation, disability, physical appearance, age, body size, race, religion, national origin, ethnicity, level of experience, language fluency, political affiliation, veteran status, pregnancy, country of origin, and any other characteristic protected under state or federal law, feels safe and welcome in our activities and community. We gain strength from diversity and actively seek participation from those who enhance it.

In order to garner the benefits of a diverse community and to reach the full potential of our mission and charge, ESIIL participants must be allowed to develop a sense of belonging and trust within a respectful, inclusive, and collaborative culture. Guiding behaviors that contribute to this culture include, but are not limited to:

## Showing Respect

- **Listen carefully** – we each bring our own styles of communication, language, and ideas, and we must do our best to accept and accommodate differences. Do not interrupt when someone is speaking and maintain an open mind when others have different ideas than yours.

- **Be present** – when engaging with others, give them your full attention. If you need to respond to outside needs, please step away from the group quietly.

- **Be kind** – offer positive, supportive comments and constructive feedback. Critique ideas, not people. Harassment, discrimination, bullying, aggression, including offensive comments, jokes, and imagery, are unacceptable, regardless of intent, and will not be tolerated.

- **Be punctual** - adhere to the schedule provided by the organizers and avoid disruptive behavior during presentations, trainings, or working sessions.

- **Respect privacy** - be mindful of the confidentiality of others. Always obtain explicit consent before recording, sharing, or using someone else’s personal information, photos, or recordings.

- **Practice good digital etiquette (netiquette)** when communicating online, whether in emails, messages, or social media - think before posting online and consider the potential impact on others. Do not share or distribute content generated by or involving others without their explicit consent.

## Being Inclusive

- **Create space for everyone to participate** – be thoughtful about who is at the table; openly address accessibility needs, and provide multiple ways to contribute.

- **Be welcoming** – ESIIL participants come from a wide range of skill levels and career stages, backgrounds, and cultures. Demonstrate that you value these different perspectives and identities through your words and actions, including through correct use of names, titles, and pronouns.

- **Be self-aware** – recognize that positionality, identity, unconscious biases, and upbringing can all affect how words and behaviors are perceived. Ensure that your words and behavior make others feel welcome.

- **Commit to ongoing learning** – the move toward inclusive, equitable, and just environmental data science is a collective journey. Continue to learn about and apply practices of inclusion, anti-racism, bystander intervention, and cultural sensitivity. None of us is perfect; all of us will, from time to time, fail to live up to our own high standards. Being perfect is not what matters; owning our mistakes and committing to clear and persistent efforts to grow and improve is.

# Being Curious

- **Check your presumptions** – we each bring our own ideas and assumptions about how the world should and does work – what are yours, and how do they affect how you interact with others? How do they shape your perception of new ideas?

- **Ask questions** – one of the strengths of interdisciplinary and diverse teams is that we all bring different knowledge and viewpoints; no one person is expected to know everything. So don’t be afraid to ask, to learn, and to share.

- **Be bold** – significant innovations don’t come from incremental efforts. Be brave in proposing and testing new ideas. When things don’t work, learn from the experience.

- **Invite feedback** – new ideas and improvements can emerge from many places when we’re open to hearing them. Check your defensiveness and listen; accept feedback as a gift toward improving our work and ourselves.

## Being Collaborative

- **Recognize that everyone is bringing something different to the table** – take the time to get to know each other. Keep an open mind, encourage ideas that are different from yours, and learn from each other’s expertise and experience.

- **Be accountable** - great team science depends on trust, communication, respect, and delivering on your commitments. Be clear about your needs, as both a requester and a responder, realistic about your time and capacity commitments, and communicate timelines and standards in advance.

- **Make assumptions explicit and provide context wherever possible** - misunderstandings are common on transdisciplinary and cross-cultural teams and can best be managed with intentionality. Check in about assumptions, and be willing to share and correct misunderstandings or mistakes when they happen. Make use of collaboration agreements, communicate clearly and avoid jargon wherever possible.

- **Respect intellectual property and Indigenous data sovereignty** – ESIIL recognizes the extractive and abusive history of scientific engagement with Native peoples, and is committed to doing better. Indigenous knowledge holders are under no obligation to share their data, stories or knowledge. Their work should always be credited, and only shared with permission. Follow guidelines for authorship, Indigenous data sovereignty, and CARE principles. Acknowledge and credit the ideas and work of others.

- **Use the resources that we provide** - take advantage of the cyberinfrastructure and data cube at your disposal, but do not use them for unrelated tasks, as it could disrupt the event, introduce security risks, undermine the spirit of collaboration and fair play, and erode trust within the event community.

- **Be safe** - never share sensitive personal information; use strong passwords for your Cyverse and GitHub accounts and do not share them with other participants; be cautious of unsolicited emails, messages, or links; and verify online contacts. If you encounter any illegal or harmful activities online related to this event, report them to Tyler McIntosh or Susan Sullivan.

**Finally, speak up if you experience or notice a dangerous situation, or someone in distress!**

# Code of Conduct: Unacceptable behaviors

We adopt the full Code of Conduct of our home institution, the University of Colorado, details of which are found [here](#). To summarize, examples of unacceptable and reportable behaviors include, but are not limited to:

- Harassment, intimidation, or discrimination in any form
- Physical or verbal abuse by anyone to anyone, including but not limited to a participant, member of the public, guest, member of any institution or sponsor
- Unwelcome sexual attention or advances
- Personal attacks directed at other guests, members, participants, etc.
- Alarming, intimidating, threatening, or hostile comments or conduct
- Inappropriate use of nudity and/or sexual images in public spaces or in presentations
- Threatening or stalking anyone
- Unauthorized use or sharing of personal or confidential information or private communication
- Continuing interactions, including but not limited to conversations, photographies, recordings, instant messages, and emails, after being asked to stop
- Ethical and scientific misconduct, including failing to credit contributions or respect intellectual property
- Engaging in any illegal activities, including hacking, cheating, or unauthorized access to systems or data
- Using the cyberinfrastructure provided by the organizers for activities unrelated to this event.
- Other conduct which could reasonably be considered inappropriate in a professional setting. 

The University of Colorado recognizes all Federal and State protected classes, which include the following: race, color, national origin, sex, pregnancy, age, marital status, disability, creed, religion, sexual orientation, gender identity, gender expression, veteran status, political affiliation or political philosophy. Mistreatment or harassment not related to protected class also has a negative impact and will be addressed by the ESIIL team.

Anyone requested to stop unacceptable behavior is expected to comply immediately.

If there is a clear violation of the code of conduct during an ESIIL event—for example, a meeting is Zoom bombed or a team member is verbally abusing another participant during a workshop— ESIIL leaders, facilitators (or their designee) or campus/local police may take any action deemed necessary and appropriate, including expelling the violator, or immediate removal of the violator from any online or in-person event or platform without warning or refund. If such actions are necessary, there will be follow up with the ESIIL Diversity Equity and Inclusion (DEI) team to determine what further action is needed (see Reporting Process and Consequences below).

## Addressing Behavior Directly

For smaller incidents that might be settled with a brief conversation, you may choose to contact the person in question or set up a (video) conversation to discuss how the behavior affected you. Please use this approach only if you feel comfortable; you do not have to carry the weight of addressing these issues yourself. If you are interested in this option but unsure how to go about it, please contact the ESIIL DEI lead, Susan Sullivan, first—she will have advice on how to make the conversation happen and is available to join you in a conversation as requested.

# Reporting Process and Consequences

We take any reports of Code of Conduct violations seriously, and aim to support those who are impacted and ensure that problematic behavior doesn’t happen again.

## Making a Report

If you believe you’re experiencing or have experienced unacceptable behavior that is counter to this code of conduct, or you are witness to this behavior happening to someone else, we encourage you to contact our DEI lead:

- **Susan Sullivan, CIRES**
  - Email: [susan.sullivan@colorado.edu](mailto:susan.sullivan@colorado.edu)

You may also choose to anonymously report behavior to ESIIL using [this form](#).

The DEI team will keep reports as confidential as possible. However, as mandatory reporters, we have an obligation to report alleged protected class violations to our home institution or to law enforcement.

### Specifically:

- Cases of potential protected-class harassment will be reported to the CU Office of Institutional Equity and Compliance.
- If the violation is made by a member of another institution, that information may also be shared with that member’s home institution by the CU Office of Institutional Equity and Compliance under Title IX.
- In some instances, harassment information may be shared with the National Science Foundation, who are the funding organization of ESIIL.

When we discuss incidents with people who are accused of misconduct (the respondent), we will anonymize details as much as possible to protect the privacy of the reporter and the person who was impacted (the complainant). In some cases, even when the details are anonymized, the respondent may guess at the identities of the reporter and complainants. If you have concerns about retaliation or your personal safety, please let us know (or note that in your report). We encourage you to report in any case, so that we can support you while keeping ESIIL members safe. In some cases, we are able to compile several anonymized reports into a pattern of behavior, and take action based on that pattern.

If you prefer to speak with someone who is not on the ESIIL leadership team, or who can maintain confidentiality, you may contact:

- **CU Ombuds**
  - Phone: 303-492-5077 (for guidance and support navigating difficult conversations)
- **CU Office of Victim Assistance**
  - Phone: 303-492-8855 

If you want more information about when to report, or how to help someone who needs to report, please review the resources at [Don’t Ignore It](#).

**Note:** The reporting party does not need to be directly involved in a code of conduct violation incident. Please make a bystander report if you observe a potentially dangerous situation, someone in distress, or violations of these guidelines, even if the situation is not happening to you.

# What Happens After a Report Is Filed

After a member of the ESIIL DEI team takes your report, they will (if necessary) consult with the appropriate support people at CU. The ESIIL DEI team will respond with a status update within 5 business days.

During this time, they, or members of the CU Office of Institutional Equity and Compliance, will:

- Meet with you or review report documentation to determine what happened
- Consult documentation of past incidents for patterns of behavior
- Discuss appropriate response(s) to the incident
- Connect with the appropriate offices and/or make those response(s)
- Determine the follow-up actions for any impacted people and/or the reporter
- Follow up with the impacted people, including connecting them with support and resources.

## As a result of this process, in minor cases ESIIL DEI may communicate with the respondent to:

- Explain what happened and the impact of their behavior
- Offer concrete examples of how to improve their behavior
- Explain consequences of their behavior, or future consequences if the behavior is repeated.

For significant infractions, follow up to the report may be turned over to the CU Office of Institutional Equity and Compliance and/or campus police.

## Possible Consequences to Code of Conduct Violations

What follows are examples of possible responses to an incident report. This list is not inclusive, and ESIIL reserves the right to take any action it deems necessary. Generally speaking, the strongest response ESIIL may take is to completely ban a user from further engagement with ESIIL activities and, as is required, report a person to the CU Office of Institutional Equity and Compliance and/or their home institution and NSF. If law enforcement should be involved, they will recommend that the complainant make that contact. Employees of CU Boulder may also be subject to consequences as determined by the institution.

In addition to the responses above, ESIIL responses may include but are not limited to the following:

- A verbal discussion in person or via phone/Zoom followed by documentation of the conversation via email
- Not publishing the video or slides of a talk that violated the code of conduct
- Not allowing a speaker who violated the code of conduct to give (further) talks
- Immediately ending any team leadership, membership, or other responsibilities and privileges that a person holds
- Temporarily banning a person from ESIIL activities
- Permanently banning a person from ESIIL activities
- Nothing, if the behavior is determined to not be a code of conduct violation

Do you need more resources?

Please don’t hesitate to contact the ESIIL DEI lead, Susan Sullivan, if you have questions or
concerns.

The CU Office of Institutional Equity and Compliance is a resource for all of us in navigating this space. They also offer resource materials that can assist you in exploring various topics and skills here.

If you have questions about what, when or how to report, or how to help someone else with
concerns, Don’t Ignore It.

CU Ombud’s Office: Confidential support to navigate university situations. (Most universities
have these resources)

The CU Office of Victims Assistance (counseling limited to CU students/staff/faculty, though
advocacy is open to everyone engaged with a CU-sponsored activity. Please look for a similar resource on your campus if you are from another institution).

National Crisis Hotlines

How are we doing?

Despite our best intentions, in some cases we may not be living up to our ideals of a positive,
supportive, inclusive, respectful and collaborative community. If you feel we could do better, we welcome your feedback. Comments, suggestions and praise are also very welcome!
Acknowledgment
By participating in this event, you agree to abide by this code of conduct and understand the consequences of violating it. We believe that a respectful and inclusive environment benefits all participants and leads to more creative and successful outcomes.
Thank you for your cooperation in making the this event a welcoming event for all. Have fun!

